@@ -4,7 +4,9 @@ use strict;
 use warnings;
 use IO::Pipe;
 use JSON::MaybeXS ();
+use Text::Amuse::Compile::Fonts;
 use Moo;
+use Data::Dumper;
 
 
 =head1 NAME
@@ -68,38 +70,17 @@ sub use_imagemagick {
 }
 
 sub try_list {
-    return {
-            serif => [
-                      'CMU Serif',
-                      'Linux Libertine O',
-                      'Charis SIL',
-                      'TeX Gyre Termes',
-                      'TeX Gyre Pagella',
-                      'TeX Gyre Schola',
-                      'TeX Gyre Bonum',
-                      'Antykwa Poltawskiego',
-                      'Antykwa Torunska',
-                      'PT Serif',
-                      'Droid Serif',
-                      'Noto Serif',
-                     ],
-            sans => [
-                     'CMU Sans Serif',
-                     'Linux Biolinum O',
-                     'Iwona',
-                     'TeX Gyre Heros',
-                     'TeX Gyre Adventor',
-                     'Droid Sans',
-                     'Noto Sans',
-                     'DejaVu Sans',
-                     'PT Sans',
-                    ],
-            mono => [
-                     'CMU Typewriter Text',
-                     'DejaVu Sans Mono',
-                     'TeX Gyre Cursor',
-                    ],
-           };
+    # pick the default list from the Fonts class and add Noto
+    my $fonts = Text::Amuse::Compile::Fonts->new;
+    my %all = (
+               serif => [ map { $_->name } $fonts->serif_fonts ],
+               mono  => [ map { $_->name } $fonts->mono_fonts ],
+               sans  => [ map { $_->name } $fonts->sans_fonts ],
+              );
+    push @{$all{serif}}, "Noto Serif";
+    push @{$all{sans}}, "Noto Sans";
+    push @{$all{mono}}, "Noto Mono";
+    return \%all;
 }
 
 sub all_fonts {
@@ -124,16 +105,20 @@ sub import_with_fclist {
     $pipe->autoflush;
     while (<$pipe>) {
         chomp;
-        if (m/(.+?)\s*:\s*(.+?)(\,.+)?\s*:\s*style=(Bold|Italic|Regular|Book|Bold\s*Italic|Oblique|Bold\s*Oblique)$/) {
+        if (m/(.+?)\s*:
+              \s*(.+?)(\,.+)?\s*:
+              \s*style=(
+                  Book|Roman|Medium|Regular|
+                  Italic|Oblique|
+                  Bold|
+                  Bold\s*Italic|Bold\s*Oblique)$/x) {
             my $file = $1;
             my $name = $2;
             my $style = lc($4);
             $style =~ s/\s//g;
-            $style =~ s/oblique/italic/;
-            $style =~ s/book/regular/;
             next unless $all{$name};
             if ($specs{$name}{files}{$style}) {
-                # warn "Duplicated font! $file $name $style $specs{$name}{files}{$style}\n";
+                warn "Duplicated font! $file $name $style $specs{$name}{files}{$style}\n";
             }
             else {
                 $specs{$name}{files}{$style} = $file;
@@ -207,16 +192,20 @@ sub import_list {
         foreach my $font (@{$list->{$type}}) {
             if (my $found = $specs->{$font}) {
                 my $files = $found->{files};
-                if (%$files and scalar(keys %$files) == 4) {
-                    push @out, {
-                                name => $font,
-                                desc => $font,
-                                type => $type,
-                                regular => $files->{regular},
-                                italic => $files->{italic},
-                                bold => $files->{bold},
-                                bolditalic => $files->{bolditalic},
-                               };
+                my %styles = (
+                              bold => $files->{bold},
+                              bolditalic => $files->{bolditalic} || $files->{boldoblique},
+                              italic => $files->{italic} || $files->{oblique},
+                              regular => $files->{regular} || $files->{book} || $files->{roman} || $files->{medium},
+                              name => $font,
+                              desc => $font,
+                              type => $type,
+                             );
+                if (grep { !$_ } values %styles) {
+                    warn "Discarding $font, missing styles: " . Dumper(\%styles);
+                }
+                else {
+                    push @out, \%styles;
                 }
             }
         }
